import React, { ReactElement, useState } from "react"
import { graphql, PageProps } from "gatsby"
import { IGatsbyImageData } from "gatsby-plugin-image"
import dayjs from "dayjs"
import { merge } from "@onegeo-suite/gatsby-theme-onegeo/src/utils"

import {
    Layout,
    Content,
    CardList,
    TitleComponent,
} from "@onegeo-suite/gatsby-theme-onegeo"

import { ViewListIcon, ViewGridIcon } from "@heroicons/react/outline"

interface INew {
    id?: string
    subtitle?: string
    title?: string
    content?: string
    abstract?: string
    image?: {
        id?: string
        imageFile?: IGatsbyImageData
    }
    options? : object
}

interface DataProps {
    directus: {
        news: INew[]
    }
}

function News({ data }: PageProps<DataProps>): ReactElement {
    const [bLayoutGrid, setLayoutGrid] = useState(false)

    const onSetLayout = () => {
        setLayoutGrid((prevState) => !prevState)
    }

    // const {
    //     title = "",
    //     layout = bLayoutGrid ? "grid" : "row"
    //     subtitle = "",
    // } = data
    const layout = bLayoutGrid ? "grid" : "row"
    const optionsCards = {
        class : {
            title: "text-primary font-bold",
            subtitle: "text-primary font-semibold",
        }
    }

    const listNews = data.directus.news.map((dt) => {
        return {
            name: dt.title,
            description: dt.abstract || dt.content,
            subtitle: dt.subtitle,
            image: dt.image?.imageFile,
            url: "/news/" + dt.slug,
            category: dt.categories,
            date: dayjs(dt.date_published).format("DD/MM/YYYY"),
            options : merge(optionsCards, dt.options),
        }
    })

    return (
        <Layout>
            <Content className="mx-64 pt-8 max-w-none">
                <div className="mt-10 p-6 lg:flex">
                    <div className="flex flex-col w-1/2">
                        <TitleComponent
                            title={"Découvrez nos actualités"}
                            className="text-primary p-2 text-2xl font-bold uppercase tracking-tight sm:text-2xl"
                        />
                        <h4
                            className={
                                "mb-6 p-2 text-5xl font-extrabold tracking-tight sm:text-5xl"
                            }
                        >
                            Actualités
                        </h4>
                    </div>
                    <div className="flex w-full items-center gap-6">
                        <button className="h-8 w-8" onClick={onSetLayout}>
                            {bLayoutGrid ? <ViewGridIcon /> : <ViewListIcon />}
                        </button>
                        <input
                            type="text"
                            placeholder="Titre, description"
                            className="input input-bordered w-full"
                        />
                    </div>
                </div>

                <CardList
                    cards={listNews}
                    layout={layout}
                    anime={bLayoutGrid}
                    className="mb-10"
                    {...optionsCards}
                />
            </Content>
        </Layout>
    )
}

export default News

export const query = graphql`
    query {
        directus {
            news(
                filter: { status: { _eq: "published" } }
                sort: "-date_published"
            ) {
                id
                slug
                content
                abstract
                title
                subtitle
                date_published
                image {
                    id
                    imageFile {
                        childImageSharp {
                            gatsbyImageData
                        }
                        name
                        publicURL
                    }
                }
                categories {
                    id
                    name
                    label
                }
            }
        }
    }
`

